@@ -387,9 +387,10 @@ c                            ! output.    wgt
       real*8 dd, rhoE
       real*8 cvh2den
       real*8 Z1, E0
+      integer ii, jj  ! ii is for incident and jj is for child; for e/g 1,  for mu/had 3
       data Z1/-1./, E0/-1./
       save Z1, E0, rhoE, dd
-
+      
       if(IncidentCopy.p.code .eq. kphoton  .and.
      *    PhotoProd )  then
 c            photon  primary and muon is interested
@@ -438,15 +439,26 @@ c           Weight and energy has
 c           E=Ethin(1)/w ; at very low energies
 c          (say < 1GeV ), E<=Ethin(1)/w begins
 c           and brodens  
-         if(iergpn .gt. Ethin(1) ) then
-            if(aergpn .gt. Ethin(1)) then
+         if( aTrack.p.code .le. kelec ) then
+            jj = 1
+         else
+            jj = 3
+         endif
+         if( iTrack.p.code .le. kelec ) then
+            ii = 1
+         else
+            ii = 3
+         endif
+
+         if(iergpn .gt. Ethin(ii) ) then
+            if(aergpn .gt. Ethin(jj)) then
 c                    Both   Ei, Ec> Ethin1; no thinning
                icon = 0
                aTrack.wgt = iTrack.wgt
 c         elseif(aergpn .gt. Ethin(2)) then 
-            elseif( aTrack.wgt .lt. Ethin(2)) then
+            elseif( aTrack.wgt .lt. Ethin(jj+1)) then
 c              
-               p = aergpn/Ethin(1)
+               p = aergpn/Ethin(jj)
                call rndc(u)
                if(u .lt. p)  then
                   icon = 0
@@ -460,8 +472,8 @@ c
             endif
 c      elseif(iergpn .gt. Ethin(2) .and.
 c     *       aergpn .gt. Ethin(2) ) then
-         elseif(iTrack.wgt .lt. Ethin(2) .and.
-     *           aTrack.wgt .lt. Ethin(2) ) then
+         elseif(iTrack.wgt .lt. Ethin(ii+1) .and.
+     *           aTrack.wgt .lt. Ethin(jj+1) ) then
             p = aergpn/iergpn
             call rndc(u)
             if(u .lt. p ) then
